Learn R Programming

ggpedigree (version 1.1.0.3)

.addOverlay: Add Overlay to ggplot Pedigree Plot

Description

Add Overlay to ggplot Pedigree Plot

Usage

.addOverlay(
  plotObject,
  config = list(overlay_include = FALSE, status_include = FALSE, focal_fill_include =
    FALSE, sex_color_include = FALSE),
  focal_fill_column = NULL,
  status_column = NULL,
  overlay_column = NULL
)

addOverlay( plotObject, config = list(overlay_include = FALSE, status_include = FALSE, focal_fill_include = FALSE, sex_color_include = FALSE), focal_fill_column = NULL, status_column = NULL, overlay_column = NULL )

Value

A ggplot object with added overlay.

Arguments

plotObject

A ggplot object.

config

A list of configuration options for customizing the plot. See getDefaultPlotConfig for details of each option. The list can include:

code_male

Integer or string. Value identifying males in the sex column. (typically 0 or 1) Default: 1

segment_spouse_color, segment_self_color

Character. Line colors for respective connection types.

segment_sibling_color, segment_parent_color, segment_offspring_color

Character. Line colors for respective connection types.

label_text_size, point_size, segment_linewidth

Numeric. Controls text size, point size, and line thickness.

generation_height

Numeric. Vertical spacing multiplier between generations. Default: 1.

shape_unknown, shape_female, shape_male, status_shape_affected

Integers. Shape codes for plotting each group.

sex_shape_labels

Character vector of labels for the sex variable. (default: c("Female", "Male", "Unknown"))

unaffected, affected

Values indicating unaffected/affected status.

sex_color_include

Logical. If TRUE, uses color to differentiate sex.

label_max_overlaps

Maximum number of overlaps allowed in repelled labels.

label_segment_color

Color used for label connector lines.

focal_fill_column

Character string specifying the column name for focal fill color.

status_column

Character string specifying the column name for affected status. Defaults to NULL.

overlay_column

Character string specifying the column name for overlay alpha values.