Rename standard internal columns in a pedigree connections data frame back to user-specified names.
.restoreNames(
connections,
personID = "personID",
momID = "momID",
dadID = "dadID",
spouseID = "spouseID",
twinID = "twinID",
famID = "famID"
)restoreNames(
connections,
personID = "personID",
momID = "momID",
dadID = "dadID",
spouseID = "spouseID",
twinID = "twinID",
famID = "famID"
)
A data frame containing connection identifiers whose columns may currently be named with internal defaults such as `personID`, `momID`, `dadID`, `spouseID`, `twinID`, `famID`.
Character string specifying the column name for individual IDs. Defaults to "personID".
Character string specifying the column name for mother IDs. Defaults to "momID".
Character string specifying the column name for father IDs. Defaults to "dadID".
Character string specifying the column name for spouse IDs. Defaults to "spouseID".
Character string specifying the column name for twin IDs. Defaults to "twinID".
Character string specifying the column name for family IDs. Defaults to "famID".