Adds a `focal_fill` column to the pedigree data based on configuration input. Supports additive, mitochondrial, and line-based modes. If `focal_fill_column` is specified, it takes priority over inferred modes.
addFocalFillColumn(
ds_ped,
config,
focal_fill_column = NULL,
famID = "famID",
matID = "matID",
patID = "patID",
personID = "personID",
fill_group_family = c("famID", "family", "family lineages", "family lines",
"family line"),
fill_group_maternal = c("maternal", "matID", "maternal line", "maternal lineages",
"maternal lines"),
fill_group_paternal = c("paternal", "patID", "paternal line", "paternal lineages",
"paternal lines")
)A data frame with a `focal_fill` column added if applicable.
A data frame already processed by `transformPed()`.
A list of configuration options for customizing the plot. See getDefaultPlotConfig for details of each option. The list can include:
Integer or string. Value identifying males in the sex column. (typically 0 or 1) Default: 1
Character. Line colors for respective connection types.
Character. Line colors for respective connection types.
Numeric. Controls text size, point size, and line thickness.
Numeric. Vertical spacing multiplier between generations. Default: 1.
Integers. Shape codes for plotting each group.
Character vector of labels for the sex variable. (default: c("Female", "Male", "Unknown"))
Values indicating unaffected/affected status.
Logical. If TRUE, uses color to differentiate sex.
Maximum number of overlaps allowed in repelled labels.
Color used for label connector lines.
Character string specifying the column name for focal fill color.
Character string specifying the column name for family IDs. Defaults to "famID".
Character string specifying the column name for maternal lines Defaults to "matID".
Character string specifying the column name for paternal lines Defaults to "patID".
Character string specifying the column name for individual IDs. Defaults to "personID".
Character vector specifying fill types for family lineage.
Character vector specifying fill types for maternal lineage.
Character vector specifying fill types for paternal lineage.