alignPedigreeWithHints: Align pedigree with hints for plotting This function aligns a...

View source: R/calcCoordinates.R

alignPedigreeWithHintsR Documentation

Align pedigree with hints for plotting This function aligns a pedigree object using hints if provided, or defaults to the default alignment settings.

Description

Align pedigree with hints for plotting This function aligns a pedigree object using hints if provided, or defaults to the default alignment settings.

Usage

alignPedigreeWithHints(ped_ped, config)

Arguments

ped_ped

A pedigree object created by 'pedigree()'.

config

A list of configuration options

Value

A data frame with the aligned positions of individuals in the pedigree.


ggpedigree documentation built on March 16, 2026, 9:07 a.m.