This function aligns a pedigree object using relations if provided, or defaults to the default alignment settings.
alignPedigreeWithRelations(
ped,
personID,
dadID,
momID,
code_male = NULL,
sexVar = "sex",
config
)A data frame with the aligned positions of individuals in the pedigree.
A data frame containing the pedigree data. Needs personID, momID, dadID, and sex columns.
Character string specifying the column name for individual IDs. Defaults to "personID".
Character string specifying the column name for father IDs. Defaults to "dadID".
Character string specifying the column name for mother IDs. Defaults to "momID".
Value used to indicate male sex. Defaults to NULL.
Character. Name of the column in `ped` for the sex variable.
List of configuration options:
Default is 1. Used by BGmisc::recodeSex().
Logical, default TRUE. Passed to `kinship2_align.pedigree`.
Logical, default TRUE. Align generations.
Numeric, default 15. Controls spacing.