| .addNodes | R Documentation |
Add Nodes to ggplot Pedigree Plot
.addNodes(
plotObject,
config,
focal_fill_column = NULL,
status_column = NULL,
affected_fill_column = NULL,
outline_color_column = NULL
)
addNodes(
plotObject,
config,
focal_fill_column = NULL,
status_column = NULL,
affected_fill_column = NULL,
outline_color_column = NULL
)
plotObject |
A ggplot object. |
config |
A list of configuration options for customizing the plot. See getDefaultPlotConfig for details of each option. The list can include:
|
focal_fill_column |
Character string specifying the column name for focal fill color. |
status_column |
Character string specifying the column name for affected status. Defaults to NULL. |
affected_fill_column |
Character string specifying the column name for conditional affected fill. When provided, individuals matching the 'affected_fill_code_affected' config will have their symbols filled. Default is NULL. |
outline_color_column |
Character string specifying the column name for outline color control. When provided, individuals matching 'outline_color_code_affected' config will have colored outlines (e.g., blue for included). Default is NULL. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.