Learn R Programming

ggpedigree (version 1.1.0.3)

formatTooltip: Format tooltip text

Description

Format tooltip text for ggplotly

Usage

formatTooltip(df, tooltip_columns, sep = ": ")

Value

A character vector of formatted tooltip text for each row in the data frame.

Arguments

df

A data frame containing the data to be displayed in the tooltip.

tooltip_columns

A character vector of column names to be included in the tooltip.

sep

A character string containing the separator for the columns