View source: R/ggpedigreeCore.R
| ggPedigree.core | R Documentation |
This function is the core implementation of the ggPedigree function. It handles the data preparation, layout calculation, and plotting of the pedigree diagram. It is not intended to be called directly by users.
ggPedigree.core(
ped,
famID = "famID",
personID = "personID",
momID = "momID",
dadID = "dadID",
spouseID = "spouseID",
matID = "matID",
patID = "patID",
twinID = "twinID",
focal_fill_column = NULL,
overlay_column = NULL,
overlays = NULL,
status_column = NULL,
code_male = NULL,
config = list(),
debug = FALSE,
hints = NULL,
sexVar = "sex",
function_name = "ggPedigree",
affected_fill_column = NULL,
outline_color_column = NULL
)
ped |
A data frame containing the pedigree data. Needs personID, momID, dadID, and sex columns. |
famID |
Character string specifying the column name for family IDs. Defaults to "famID". |
personID |
Character string specifying the column name for individual IDs. Defaults to "personID". |
momID |
Character string specifying the column name for mother IDs. Defaults to "momID". |
dadID |
Character string specifying the column name for father IDs. Defaults to "dadID". |
spouseID |
Character string specifying the column name for spouse IDs. Defaults to "spouseID". |
matID |
Character string specifying the column name for maternal lines Defaults to "matID". |
patID |
Character string specifying the column name for paternal lines Defaults to "patID". |
twinID |
Character string specifying the column name for twin IDs. Defaults to "twinID". |
focal_fill_column |
Character string specifying the column name for focal fill color. |
overlay_column |
Character string specifying the column name for overlay alpha values.
For a single overlay, this is the simplest interface. For multiple overlays, use
the |
overlays |
A list of overlay specifications for adding multiple independent overlay
layers. Each element should be a list with at minimum a |
status_column |
Character string specifying the column name for affected status. Defaults to NULL. |
code_male |
Integer or string. Value identifying males in the sex column. (typically 0 or 1) Default: 1 |
config |
A list of configuration options for customizing the plot. See getDefaultPlotConfig for details of each option. The list can include:
|
debug |
Logical. If TRUE, prints debugging information. Default: FALSE. |
hints |
Data frame with hints for layout adjustments. Default: NULL. |
sexVar |
Character string specifying the column name for sex. Defaults to "sex". |
affected_fill_column |
Character string specifying the column name for conditional affected fill. When provided, individuals matching the 'affected_fill_code_affected' config will have their symbols filled. Default is NULL. |
outline_color_column |
Character string specifying the column name for outline color control. When provided, individuals matching 'outline_color_code_affected' config will have colored outlines (e.g., blue for included). Default is NULL. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.