kinship2_alignped2: Align pedigree - Process a set of siblings

View source: R/kinship2_alignped2.R

kinship2_alignped2R Documentation

Align pedigree - Process a set of siblings

Description

This is an internal helper function for pedigree alignment. It processes a set of siblings, ordering them according to hints and calling kinship2_alignped1 for each sibling. The results are merged together using kinship2_alignped3.

Usage

kinship2_alignped2(x, dad, mom, level, horder, packed, spouselist)

Arguments

x

Integer vector of sibling IDs to process

dad

Integer vector of father indices

mom

Integer vector of mother indices

level

Integer vector indicating the generation level of each subject

horder

Numeric vector of hint order for positioning subjects

packed

Logical, if TRUE uses compact packing algorithm

spouselist

Matrix defining spouse relationships

Value

A list containing the aligned pedigree structure for the sibling group:

nid

Matrix of subject IDs at each level and position

pos

Matrix of horizontal positions

fam

Matrix of family indices

n

Vector of counts per level

spouselist

Updated spouse list


ggpedigree documentation built on March 16, 2026, 9:07 a.m.