Learn R Programming

ggpedigree (version 1.1.0.3)

kinship2_shift: Shift a subject and his twins left or right among siblings used in autohint to resolve duplicate positions

Description

Shift a subject and his twins left or right among siblings used in autohint to resolve duplicate positions

Usage

kinship2_shift(id, sibs, goleft, hint, twinrel, twinset)

Arguments

Value

Updated hint vector