View source: R/ggpedigreeCoreHelpers.R
| preparePedigreeData | R Documentation |
This function checks and prepares the pedigree data frame for use in ggPedigree.
preparePedigreeData(
ped,
famID = "famID",
personID = "personID",
momID = "momID",
dadID = "dadID",
matID = "matID",
patID = "patID",
config = list(focal_fill_include = TRUE, focal_fill_component = "maternal",
recode_missing_ids = TRUE, add_phantoms = FALSE, code_male = "M", code_female = "F",
code_na = NA),
fill_group_paternal = c("paternal", "patID", "paternal line", "paternal lineages",
"paternal lines"),
fill_group_maternal = c("maternal", "matID", "maternal line", "maternal lineages",
"maternal lines"),
fill_group_family = c("family", "famID", "family line", "family lineages",
"family lines"),
status_column = NULL,
focal_fill_column = NULL,
sexVar = "sex"
)
ped |
A data frame containing the pedigree data. Needs personID, momID, dadID, and sex columns. |
famID |
Character string specifying the column name for family IDs. Defaults to "famID". |
personID |
Character string specifying the column name for individual IDs. Defaults to "personID". |
momID |
Character string specifying the column name for mother IDs. Defaults to "momID". |
dadID |
Character string specifying the column name for father IDs. Defaults to "dadID". |
matID |
Character string specifying the column name for maternal lines Defaults to "matID". |
patID |
Character string specifying the column name for paternal lines Defaults to "patID". |
config |
A list of configuration options for customizing the plot. See getDefaultPlotConfig for details of each option. The list can include:
|
fill_group_paternal |
A character vector specifying which paternal components to fill. |
fill_group_maternal |
A character vector specifying which maternal components to fill. |
fill_group_family |
A character vector specifying the family fill group names. |
status_column |
Character string specifying the column name for affected status. Defaults to NULL. |
focal_fill_column |
Character string specifying the column name for focal fill color. |
sexVar |
Character string specifying the column name for sex. Defaults to "sex". |
A data frame with the prepared pedigree data.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.