View source: R/ggpedigreeHelpers.R
| recodeMissingIDs | R Documentation |
This function recodes missing IDs in the pedigree data frame to NA. It checks for specified missing codes (both numeric and character) in their respective columns.
recodeMissingIDs(
ped,
momID = "momID",
dadID = "dadID",
personID = "personID",
famID = "famID",
matID = "matID",
patID = "patID",
missing_code_numeric = 0,
missing_code_character = c("0", "NA", "na", ""),
config = list()
)
ped |
A data frame containing the pedigree data. Needs personID, momID, dadID, and sex columns. |
momID |
Character string specifying the column name for mother IDs. Defaults to "momID". |
dadID |
Character string specifying the column name for father IDs. Defaults to "dadID". |
personID |
Character string specifying the column name for individual IDs. Defaults to "personID". |
famID |
Character string specifying the column name for family IDs. Defaults to "famID". |
matID |
Character string specifying the column name for maternal lines Defaults to "matID". |
patID |
Character string specifying the column name for paternal lines Defaults to "patID". |
missing_code_numeric |
Numeric code representing missing IDs (default is 0). |
missing_code_character |
Character vector representing missing IDs (default is c("0", "NA", "na", "")). |
config |
A list of configuration options for customizing the plot. See getDefaultPlotConfig for details of each option. The list can include:
|
A data frame with missing IDs recoded to NA.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.