| redsquirrels | R Documentation |
A tidy data frame of life‐history and reproductive metrics for 7,799 individual red squirrels from the Kluane Red Squirrel Project (1987–present).
data(redsquirrels)
data(redsquirrels_full)
## 'redsquirrels_full' A data frame with 7799 rows and 16 columns:
Unique identifier for each squirrel
Unique identifiers for each squirrel's parents
Biological sex of the squirrel
Unique identifier for each family. Derived from ped2fam
Birth year of the squirrel
Death year of the squirrel
lifetime reproductive success for the squirrel
Mean annual reproductive success for the squirrel
Maximum ARS value for the squirrel
Median ARS value for the squirrel
Minimum ARS value for the squirrel
Standard deviation of ARS values for the squirrel
Number of ARS values for the squirrel
First year of ARS data for the squirrel
Last year of ARS data for the squirrel
...
## 'redsquirrels'
A data frame with 5251 rows and 16 columns:
A subset of redsquirrels_full intended for convenient analysis and examples.
(Same variables as redsquirrels_full, with fewer rows.)
An object of class tbl_df (inherits from tbl, data.frame) with 7799 rows and 16 columns.
#' This package provides two related datasets:
redsquirrels_full: the complete dataset from the published source
redsquirrels: a more workable subset derived from redsquirrels_full
Each row corresponds to one squirrel with associated pedigree links and reproductive success summaries.
The original data are published under a CC0 1.0 Universal Public Domain Dedication:
McFarlane, S. Eryn; Boutin, Stan; Humphries, Murray M. et al. (2015). Data from: Very low levels of direct additive genetic variance in fitness and fitness components in a red squirrel population [Dataset]. Dryad. <https://doi.org/10.5061/dryad.n5q05>
<https://doi.org/10.5061/dryad.n5q05>
# Load the red squirrels datasets
data(redsquirrels)
data(redsquirrels_full)
# View the structure of the dataset(s)
str(redsquirrels)
str(redsquirrels_full)
# Plot a pedigree for a single family
if (requireNamespace("ggplot2", quietly = TRUE)) {
# Select one family to plot
family_data <- subset(redsquirrels, famID == 160)
# Create a pedigree plot
ggPedigree(family_data,
personID = "personID",
momID = "momID",
dadID = "dadID",
sex = "sex",
config = list(
add_phantoms = TRUE,
code_male = "M"
)
)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.