Learn R Programming

ggpedigree (version 1.1.0.3)

alignPedigreeWithHints: Align pedigree with hints for plotting This function aligns a pedigree object using hints if provided, or defaults to the default alignment settings.

Description

Align pedigree with hints for plotting This function aligns a pedigree object using hints if provided, or defaults to the default alignment settings.

Usage

alignPedigreeWithHints(ped_ped, config)

Value

A data frame with the aligned positions of individuals in the pedigree.

Arguments

ped_ped

A pedigree object created by `pedigree()`.

config

A list of configuration options