Align pedigree with hints for plotting This function aligns a pedigree object using hints if provided, or defaults to the default alignment settings.
alignPedigreeWithHints(ped_ped, config)A data frame with the aligned positions of individuals in the pedigree.
A pedigree object created by `pedigree()`.
A list of configuration options