| .addShapeOverlay | R Documentation |
Draws a shape (cross, slash, or x) over symbols of matching individuals. Used when overlay_mode is "shape" to draw markers on top of pedigree symbols (e.g., cross for deceased individuals).
.addShapeOverlay(plotObject, config, overlay_column, overlay_spec = NULL)
addShapeOverlay(plotObject, config, overlay_column, overlay_spec = NULL)
plotObject |
A ggplot object. |
config |
A list of configuration options for customizing the plot. See getDefaultPlotConfig for details of each option. The list can include:
|
overlay_column |
Character string specifying the column name for overlay status. |
overlay_spec |
Optional list of per-overlay settings that override config defaults.
Recognized keys: |
A ggplot object with shape overlay markers added.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.