This is an internal helper function for pedigree alignment. It processes a set of siblings, ordering them according to hints and calling kinship2_alignped1 for each sibling. The results are merged together using kinship2_alignped3.
kinship2_alignped2(x, dad, mom, level, horder, packed, spouselist)A list containing the aligned pedigree structure for the sibling group:
Matrix of subject IDs at each level and position
Matrix of horizontal positions
Matrix of family indices
Vector of counts per level
Updated spouse list
Integer vector of sibling IDs to process
Integer vector of father indices
Integer vector of mother indices
Integer vector indicating the generation level of each subject
Numeric vector of hint order for positioning subjects
Logical, if TRUE uses compact packing algorithm
Matrix defining spouse relationships