View source: R/kinship2_bitSize.R
| kinship2_bitSize | R Documentation |
This function calculates the bit size of a pedigree, which is a measure of the information content. The bit size is calculated as 2 * (number of non-founders) - (number of founders). This is used in pedigree.shrink functions.
kinship2_bitSize(ped)
ped |
A pedigree object |
A list containing:
bitSize |
The bit size of the pedigree |
nFounder |
The number of founders in the pedigree |
nNonFounder |
The number of non-founders in the pedigree |
## Not run:
# Example requires a pedigree object
# ped <- pedigree(id=1:5, dadid=c(0,0,1,1,1), momid=c(0,0,2,2,2),
# sex=c(1,2,1,2,1))
# kinship2_bitSize(ped)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.