Learn R Programming

ggpedigree (version 1.1.0.3)

kinship2_bitSize: Calculate the bit size of a pedigree

Description

This function calculates the bit size of a pedigree, which is a measure of the information content. The bit size is calculated as 2 * (number of non-founders) - (number of founders). This is used in pedigree.shrink functions.

Usage

kinship2_bitSize(ped)

Value

A list containing:

bitSize

The bit size of the pedigree

nFounder

The number of founders in the pedigree

nNonFounder

The number of non-founders in the pedigree

Arguments

ped

A pedigree object

Examples

Run this code
if (FALSE) {
# Example requires a pedigree object
# ped <- pedigree(id=1:5, dadid=c(0,0,1,1,1), momid=c(0,0,2,2,2),
#                 sex=c(1,2,1,2,1))
# kinship2_bitSize(ped)
}

Run the code above in your browser using DataLab